@@ -54,18 +54,22 @@ doubleGauss.fit <- function(data, col, concave = TRUE, diffs = FALSE, rho.0 = 0.
 	# Save parameter estimates
 	coef.id1 <-  matrix(NA, ncol = 6, nrow = N.sub1)
 	sdev.id1 <-  matrix(NA, ncol = 6, nrow = N.sub1)
+	sdev.id1.cov <- vector("list", N.sub1)
 	sigma.id1 <- matrix(NA, ncol = 1, nrow = N.sub1)
 
 	coef.id2 <-  matrix(NA, ncol = 6, nrow = N.sub2)
 	sdev.id2 <-  matrix(NA, ncol = 6, nrow = N.sub2)
+	sdev.id2.cov <- vector("list", N.sub2)
 	sigma.id2 <- matrix(NA, ncol = 1, nrow = N.sub2)
 	
 	coef.id3 <-  matrix(NA, ncol = 6, nrow = N.sub1)
 	sdev.id3 <-  matrix(NA, ncol = 6, nrow = N.sub1)
+	sdev.id3.cov <- vector("list", N.sub1)
 	sigma.id3 <- matrix(NA, ncol = 1, nrow = N.sub1)
 	
 	coef.id4 <-  matrix(NA, ncol = 6, nrow = N.sub2)
 	sdev.id4 <-  matrix(NA, ncol = 6, nrow = N.sub2)
+	sdev.id4.cov <- vector("list", N.sub2)
 	sigma.id4 <- matrix(NA, ncol = 1, nrow = N.sub2)
 	
 	dgauss <- function(time, mu, ht, sig1, sig2, base1, base2) {
@@ -96,6 +100,7 @@ doubleGauss.fit <- function(data, col, concave = TRUE, diffs = FALSE, rho.0 = 0.
 			if(is.null(fit.curve$fit)) {
 				coef.id1[id,] <- rep(NA, 6)
 				sdev.id1[id,] <- rep(NA, 6)
+				sdev.id1.cov[[id]] <- matrix(NA, nrow = 6, ncol = 6)
 				sigma.id1[id,] <- NA
 				cor.1[id] <- NA
 				R2.g1.1[id] <- NA
@@ -105,6 +110,7 @@ doubleGauss.fit <- function(data, col, concave = TRUE, diffs = FALSE, rho.0 = 0.
 			
 				coef.id1[id,] <- coef(fit.curve)
 				sdev.id1[id,] <- sqrt(diag(fit.curve$varBeta))
+				sdev.id1.cov[[id]] <- fit.curve$varBeta
 				sigma.id1[id,] <- fit.curve$sigma
 						
 				SSY <- sum((y.fix - mean(y.fix)) ^ 2)
@@ -130,6 +136,7 @@ doubleGauss.fit <- function(data, col, concave = TRUE, diffs = FALSE, rho.0 = 0.
 				if(is.null(fit.curve$fit)) {
 					coef.id3[id,] <- rep(NA, 6)
 					sdev.id3[id,] <- rep(NA, 6)
+					sdev.id3.cov[[id]] <- matrix(NA, nrow = 6, ncol = 6)
 					sigma.id3[id,] <- NA
 					cor.3[id] <- NA
 					R2.g1.2[id] <- NA
@@ -139,6 +146,7 @@ doubleGauss.fit <- function(data, col, concave = TRUE, diffs = FALSE, rho.0 = 0.
 				
 					coef.id3[id,] <- coef(fit.curve)
 					sdev.id3[id,] <- sqrt(diag(fit.curve$varBeta))
+					sdev.id3.cov[[id]] <- fit.curve$varBeta
 					sigma.id3[id,] <- fit.curve$sigma
 							
 					SSY <- sum((y.fix - mean(y.fix)) ^ 2)
@@ -170,6 +178,7 @@ doubleGauss.fit <- function(data, col, concave = TRUE, diffs = FALSE, rho.0 = 0.
 			if(is.null(fit.curve$fit)) {
 				coef.id2[id,] <- rep(NA, 6)
 				sdev.id2[id,] <- rep(NA, 6)
+				sdev.id2.cov[[id]] <- matrix(NA, nrow = 6, ncol = 6)
 				sigma.id2[id,] <- NA
 				cor.2[id] <- NA
 				R2.g2.1[id] <- NA
@@ -179,6 +188,7 @@ doubleGauss.fit <- function(data, col, concave = TRUE, diffs = FALSE, rho.0 = 0.
 			
 				coef.id2[id,] <- coef(fit.curve)
 				sdev.id2[id,] <- sqrt(diag(fit.curve$varBeta))
+				sdev.id2.cov[[id]] <- fit.curve$varBeta
 				sigma.id2[id,] <- fit.curve$sigma
 						
 				SSY <- sum((y.fix - mean(y.fix)) ^ 2)
@@ -204,6 +214,7 @@ doubleGauss.fit <- function(data, col, concave = TRUE, diffs = FALSE, rho.0 = 0.
 				if(is.null(fit.curve$fit)) {
 					coef.id4[id,] <- rep(NA, 6)
 					sdev.id4[id,] <- rep(NA, 6)
+					sdev.id4.cov[[id]] <- matrix(NA, nrow = 6, ncol = 6)
 					sigma.id4[id,] <- NA
 					cor.4[id] <- NA
 					R2.g2.2[id] <- NA
@@ -213,6 +224,7 @@ doubleGauss.fit <- function(data, col, concave = TRUE, diffs = FALSE, rho.0 = 0.
 				
 					coef.id4[id,] <- coef(fit.curve)
 					sdev.id4[id,] <- sqrt(diag(fit.curve$varBeta))
+					sdev.id4.cov[[id]] <- fit.curve$varBeta
 					sigma.id4[id,] <- fit.curve$sigma
 							
 					SSY <- sum((y.fix - mean(y.fix)) ^ 2)
@@ -248,6 +260,7 @@ doubleGauss.fit <- function(data, col, concave = TRUE, diffs = FALSE, rho.0 = 0.
 			if(is.null(fit.curve$fit)) {
 				coef.1 <- rep(NA, 6)
 				sdev.1 <- rep(NA, 6)
+				sdev.1.cov <- matrix(NA, nrow = 6, ncol = 6)
 				sigma.1 <- NA
 				cor.temp.1 <- NA
 				R2.1 <- NA
@@ -257,6 +270,7 @@ doubleGauss.fit <- function(data, col, concave = TRUE, diffs = FALSE, rho.0 = 0.
 			
 				coef.1 <- coef(fit.curve)
 				sdev.1 <- sqrt(diag(fit.curve$varBeta))
+				sdev.1.cov <- fit.curve$varBeta
 				sigma.1 <- fit.curve$sigma
 						
 				SSY <- sum((y.fix - mean(y.fix)) ^ 2)
@@ -277,6 +291,7 @@ doubleGauss.fit <- function(data, col, concave = TRUE, diffs = FALSE, rho.0 = 0.
 				if(is.null(fit.curve$fit)) {
 					coef.2 <- rep(NA, 6)
 					sdev.2 <- rep(NA, 6)
+					sdev.2.cov <- matrix(NA, nrow = 6, ncol = 6)
 					sigma.2 <- NA
 					cor.temp.2 <- NA
 					R2.2 <- NA
@@ -286,6 +301,7 @@ doubleGauss.fit <- function(data, col, concave = TRUE, diffs = FALSE, rho.0 = 0.
 				
 					coef.2 <- coef(fit.curve)
 					sdev.2 <- sqrt(diag(fit.curve$varBeta))
+					sdev.2.cov <- fit.curve$varBeta
 					sigma.2 <- fit.curve$sigma
 							
 					SSY <- sum((y.fix - mean(y.fix)) ^ 2)
@@ -297,27 +313,47 @@ doubleGauss.fit <- function(data, col, concave = TRUE, diffs = FALSE, rho.0 = 0.
 				}
 			}
 			if(diffs) {
-				out <- c(coef.1, sdev.1, sigma.1, R2.1, cor.temp.1, coef.2, sdev.2, sigma.2, R2.2, cor.temp.2)
+				out <- c(coef.1, sdev.1.cov[lower.tri(sdev.1.cov, diag = TRUE)], sigma.1, R2.1, cor.temp.1,
+					coef.2, sdev.2.cov[lower.tri(sdev.1.cov, diag = TRUE)], sigma.2, R2.2, cor.temp.2)
 			} else {
-				out <- c(coef.1, sdev.1, sigma.1, R2.1, cor.temp.1)
+				out <- c(coef.1, sdev.1.cov[lower.tri(sdev.1.cov, diag = TRUE)], sigma.1, R2.1, cor.temp.1)
 			}
 			out
 			
 		}
 		
 		coef.id1 <- for.out[,1:6]
-		sdev.id1 <- for.out[,7:12]
-		sigma.id1[,1] <- as.numeric(for.out[,13])
-		R2.g1.1 <- as.numeric(for.out[,14])
-		cor.1 <- as.numeric(for.out[,15])
+		sdev.id1 <- for.out[,7:27]
+		sigma.id1[,1] <- as.numeric(for.out[,28])
+		R2.g1.1 <- as.numeric(for.out[,29])
+		cor.1 <- as.numeric(for.out[,30])
 		if(diffs) {
-			coef.id3 <- for.out[,16:21]
-			sdev.id3 <- for.out[,22:27]
-			sigma.id3[,1] <- as.numeric(for.out[,28])
-			R2.g1.2 <- as.numeric(for.out[,29])
-			cor.3 <- as.numeric(for.out[,30])
+			coef.id3 <- for.out[,31:36]
+			sdev.id3 <- for.out[,37:57]
+			sigma.id3[,1] <- as.numeric(for.out[,58])
+			R2.g1.2 <- as.numeric(for.out[,59])
+			cor.3 <- as.numeric(for.out[,60])
 		}
-
+		
+		# sdev.id1 passed as a vector. Recreate covariance matrix.
+		sdev.id1.cov <- lapply(split(sdev.id1, seq(nrow(sdev.id1))), function(x) {
+			mat <- matrix(NA, ncol = 6, nrow = 6)
+			mat[lower.tri(mat, diag = TRUE)] <- x
+			mat[upper.tri(mat, diag = FALSE)] <- t(mat)[upper.tri(mat, diag = FALSE)]
+			mat
+		} )
+		sdev.id1 <- vapply(sdev.id1.cov, function(x) sqrt(diag(x)), numeric(6))
+		
+		if(diffs) {
+			sdev.id3.cov <- lapply(split(sdev.id3, seq(nrow(sdev.id3))), function(x) {
+				mat <- matrix(NA, ncol = 6, nrow = 6)
+				mat[lower.tri(mat, diag = TRUE)] <- x
+				mat[upper.tri(mat, diag = FALSE)] <- t(mat)[upper.tri(mat, diag = FALSE)]
+				mat
+			} )
+			sdev.id3 <- vapply(sdev.id3.cov, function(x) sqrt(diag(x)), numeric(6))
+		}
+		
 		for.out <- foreach(id = 1:N.g2, .combine = rbind) %dopar% {
 			if(diffs) {
 				y2id <- subset(data, data$Subject == id.nums.g2[id] & data$Group == groups[2] & data$Curve == 1)
@@ -332,6 +368,7 @@ doubleGauss.fit <- function(data, col, concave = TRUE, diffs = FALSE, rho.0 = 0.
 			if(is.null(fit.curve$fit)) {
 				coef.1 <- rep(NA, 6)
 				sdev.1 <- rep(NA, 6)
+				sdev.id1.cov <- matrix(NA, nrow = 6, ncol = 6)
 				sigma.1 <- NA
 				cor.temp.1 <- NA
 				R2.1 <- NA
@@ -341,6 +378,7 @@ doubleGauss.fit <- function(data, col, concave = TRUE, diffs = FALSE, rho.0 = 0.
 			
 				coef.1 <- coef(fit.curve)
 				sdev.1 <- sqrt(diag(fit.curve$varBeta))
+				sdev.id1.cov <- fit.curve$varBeta
 				sigma.1 <- fit.curve$sigma
 						
 				SSY <- sum((y.fix - mean(y.fix)) ^ 2)
@@ -361,6 +399,7 @@ doubleGauss.fit <- function(data, col, concave = TRUE, diffs = FALSE, rho.0 = 0.
 				if(is.null(fit.curve$fit)) {
 					coef.2 <- rep(NA, 6)
 					sdev.2 <- rep(NA, 6)
+					sdev.id2.cov <- matrix(NA, nrow = 6, ncol = 6)
 					sigma.2 <- NA
 					cor.temp.2 <- NA
 					R2.2 <- NA
@@ -370,6 +409,7 @@ doubleGauss.fit <- function(data, col, concave = TRUE, diffs = FALSE, rho.0 = 0.
 				
 					coef.2 <- coef(fit.curve)
 					sdev.2 <- sqrt(diag(fit.curve$varBeta))
+					sdev.id2.cov <- fit.curve$varBeta
 					sigma.2 <- fit.curve$sigma
 							
 					SSY <- sum((y.fix - mean(y.fix)) ^ 2)
@@ -382,24 +422,44 @@ doubleGauss.fit <- function(data, col, concave = TRUE, diffs = FALSE, rho.0 = 0.
 			}
 			
 			if(diffs) {
-				out <- c(coef.1, sdev.1, sigma.1, R2.1, cor.temp.1, coef.2, sdev.2, sigma.2, R2.2, cor.temp.2)
+				out <- c(coef.1, sdev.1.cov[lower.tri(sdev.1.cov, diag = TRUE)], sigma.1, R2.1, cor.temp.1,
+					coef.2, sdev.2.cov[lower.tri(sdev.1.cov, diag = TRUE)], sigma.2, R2.2, cor.temp.2)
 			} else {
-				out <- c(coef.1, sdev.1, sigma.1, R2.1, cor.temp.1)
+				out <- c(coef.1, sdev.1.cov[lower.tri(sdev.1.cov, diag = TRUE)], sigma.1, R2.1, cor.temp.1)
 			}
 			out
 		}
 		
 		coef.id2 <- for.out[,1:6]
-		sdev.id2 <- for.out[,7:12]
-		sigma.id2[,1] <- as.numeric(for.out[,13])
-		R2.g2.1 <- as.numeric(for.out[,14])
-		cor.2 <- as.numeric(for.out[,15])
+		sdev.id2 <- for.out[,7:27]
+		sigma.id2[,1] <- as.numeric(for.out[,28])
+		R2.g2.1 <- as.numeric(for.out[,29])
+		cor.2 <- as.numeric(for.out[,30])
 		if(diffs) {
-			coef.id4 <- for.out[,16:21]
-			sdev.id4 <- for.out[,22:27]
-			sigma.id4[,1] <- as.numeric(for.out[,28])
-			R2.g2.2 <- as.numeric(for.out[,29])
-			cor.4 <- as.numeric(for.out[,30])
+			coef.id4 <- for.out[,31:36]
+			sdev.id4 <- for.out[,37:57]
+			sigma.id4[,1] <- as.numeric(for.out[,58])
+			R2.g2.2 <- as.numeric(for.out[,59])
+			cor.4 <- as.numeric(for.out[,60])
+		}
+		
+		# sdev.id1 passed as a vector. Recreate covariance matrix.
+		sdev.id2.cov <- lapply(split(sdev.id2, seq(nrow(sdev.id2))), function(x) {
+			mat <- matrix(NA, ncol = 6, nrow = 6)
+			mat[lower.tri(mat, diag = TRUE)] <- x
+			mat[upper.tri(mat, diag = FALSE)] <- t(mat)[upper.tri(mat, diag = FALSE)]
+			mat
+		} )
+		sdev.id2 <- vapply(sdev.id2.cov, function(x) sqrt(diag(x)), numeric(6))
+		
+		if(diffs) {
+			sdev.id4.cov <- lapply(split(sdev.id4, seq(nrow(sdev.id4))), function(x) {
+				mat <- matrix(NA, ncol = 6, nrow = 6)
+				mat[lower.tri(mat, diag = TRUE)] <- x
+				mat[upper.tri(mat, diag = FALSE)] <- t(mat)[upper.tri(mat, diag = FALSE)]
+				mat
+			} )
+			sdev.id4 <- vapply(sdev.id4.cov, function(x) sqrt(diag(x)), numeric(6))
 		}
 		
 		stopCluster(cl)
@@ -467,5 +527,6 @@ doubleGauss.fit <- function(data, col, concave = TRUE, diffs = FALSE, rho.0 = 0.
 		id.nums.g1 = id.nums.g1, id.nums.g2 = id.nums.g2,
     groups = groups, time.all = time.all, N.g1 = N.g1, N.g2 = N.g2, concave = concave, model = "dgauss",
 		R2.g1.1 = R2.g1.1, R2.g2.1 = R2.g2.1, R2.g1.2 = R2.g1.2, R2.g2.2 = R2.g2.2, diffs = diffs, cor = cor,
-		cor.1 = cor.1, cor.2 = cor.2, cor.3 = cor.3, cor.4 = cor.4)
+		cor.1 = cor.1, cor.2 = cor.2, cor.3 = cor.3, cor.4 = cor.4,
+		sdev.id1.cov = sdev.id1.cov, sdev.id2.cov = sdev.id2.cov, sdev.id3.cov = sdev.id3.cov, sdev.id4.cov = sdev.id4.cov)
 }
\ No newline at end of file
