@@ -58,18 +58,22 @@ logistic.refit <- function(part1.list, subj = NULL, group = NULL, curves = NULL,
 	
 	coef.id1 <- part1.list$coef.id1
 	sdev.id1 <- part1.list$sdev.id1
+	sdev.id1.cov <- part1.list$sdev.id1.cov
 	sigma.id1 <- part1.list$sigma.id1
 	
 	coef.id2 <- part1.list$coef.id2
 	sdev.id2 <- part1.list$sdev.id2
+	sdev.id2.cov <- part1.list$sdev.id2.cov
 	sigma.id2 <- part1.list$sigma.id2
 	
 	coef.id3 <- part1.list$coef.id3
 	sdev.id3 <- part1.list$sdev.id3
+	sdev.id3.cov <- part1.list$sdev.id3.cov
 	sigma.id3 <- part1.list$sigma.id3
 	
 	coef.id4 <- part1.list$coef.id4
 	sdev.id4 <- part1.list$sdev.id4
+	sdev.id4.cov <- part1.list$sdev.id4.cov
 	sigma.id4 <- part1.list$sigma.id4
 	
 	R2.g1.1 <- part1.list$R2.g1.1
@@ -111,7 +115,7 @@ logistic.refit <- function(part1.list, subj = NULL, group = NULL, curves = NULL,
 				old.cor <- cor.3[subj[i]]
 				if(is.null(fit.curve$fit)) {
 					coef.id3[subj[i],] <- rep(NA, 4)
-					sdev.id3[subj[i],] <- rep(NA, 4)
+					sdev.id3.cov[[subj[i]]] <- matrix(NA, nrow = 4, ncol = 4)
 					sigma.id3[subj[i],] <- NA
 					cor.3[subj[i]] <- NA
 					R2.g1.2[subj[i]] <- NA
@@ -120,7 +124,7 @@ logistic.refit <- function(part1.list, subj = NULL, group = NULL, curves = NULL,
 					cor.3[subj[i]] <- fit.curve$cor
 					fit.curve <- fit.curve$fit
 					coef.id3[subj[i],] <- coef(fit.curve)
-					sdev.id3[subj[i],] <- sqrt(diag(fit.curve$varBeta))
+					sdev.id3.cov[[subj[i]]] <- fit.curve$varBeta
 					sigma.id3[subj[i],] <- fit.curve$sigma
 					
 					SSY <- sum((y.fix - mean(y.fix)) ^ 2)
@@ -143,7 +147,7 @@ logistic.refit <- function(part1.list, subj = NULL, group = NULL, curves = NULL,
 				old.cor <- cor.1[subj[i]]
 				if(is.null(fit.curve$fit)) {
 					coef.id1[subj[i],] <- rep(NA, 4)
-					sdev.id1[subj[i],] <- rep(NA, 4)
+					sdev.id1.cov[[subj[i]]] <- matrix(NA, nrow = 4, ncol = 4)
 					sigma.id1[subj[i],] <- NA
 					cor.1[subj[i]] <- NA
 					R2.g1.1[subj[i]] <- NA
@@ -152,7 +156,7 @@ logistic.refit <- function(part1.list, subj = NULL, group = NULL, curves = NULL,
 					cor.1[subj[i]] <- fit.curve$cor
 					fit.curve <- fit.curve$fit
 					coef.id1[subj[i],] <- coef(fit.curve)
-					sdev.id1[subj[i],] <- sqrt(diag(fit.curve$varBeta))
+					sdev.id1.cov[[subj[i]]] <- fit.curve$varBeta
 					sigma.id1[subj[i],] <- fit.curve$sigma
 					
 					SSY <- sum((y.fix - mean(y.fix)) ^ 2)
@@ -185,7 +189,7 @@ logistic.refit <- function(part1.list, subj = NULL, group = NULL, curves = NULL,
 				old.cor <- cor.4[subj[i]]
 				if(is.null(fit.curve$fit)) {
 					coef.id4[subj[i],] <- rep(NA, 4)
-					sdev.id4[subj[i],] <- rep(NA, 4)
+					sdev.id4.cov[[subj[i]]] <- matrix(NA, nrow = 4, ncol = 4)
 					sigma.id4[subj[i],] <- NA
 					cor.4[subj[i]] <- NA
 					R2.g2.2[subj[i]] <- NA
@@ -194,7 +198,7 @@ logistic.refit <- function(part1.list, subj = NULL, group = NULL, curves = NULL,
 					cor.4[subj[i]] <- fit.curve$cor
 					fit.curve <- fit.curve$fit
 					coef.id4[subj[i],] <- coef(fit.curve)
-					sdev.id4[subj[i],] <- sqrt(diag(fit.curve$varBeta))
+					sdev.id4.cov[[subj[i]]] <- fit.curve$varBeta
 					sigma.id4[subj[i],] <- fit.curve$sigma
 					
 					SSY <- sum((y.fix - mean(y.fix)) ^ 2)
@@ -217,7 +221,7 @@ logistic.refit <- function(part1.list, subj = NULL, group = NULL, curves = NULL,
 				old.cor <- cor.2[subj[i]]
 				if(is.null(fit.curve$fit)) {
 					coef.id2[subj[i],] <- rep(NA, 4)
-					sdev.id2[subj[i],] <- rep(NA, 4)
+					sdev.id2.cov[[subj[i]]] <- matrix(NA, nrow = 4, ncol = 4)
 					sigma.id2[subj[i],] <- NA
 					cor.2[subj[i]] <- NA
 					R2.g2.1[subj[i]] <- NA
@@ -226,7 +230,7 @@ logistic.refit <- function(part1.list, subj = NULL, group = NULL, curves = NULL,
 					cor.2[subj[i]] <- fit.curve$cor
 					fit.curve <- fit.curve$fit
 					coef.id2[subj[i],] <- coef(fit.curve)
-					sdev.id2[subj[i],] <- sqrt(diag(fit.curve$varBeta))
+					sdev.id2.cov[[subj[i]]] <- fit.curve$varBeta
 					sigma.id2[subj[i],] <- fit.curve$sigma
 					
 					SSY <- sum((y.fix - mean(y.fix)) ^ 2)
@@ -249,16 +253,16 @@ logistic.refit <- function(part1.list, subj = NULL, group = NULL, curves = NULL,
 	}
 	
 	part1.list$coef.id1 <- coef.id1 
-	part1.list$sdev.id1 <- sdev.id1 
+	part1.list$sdev.id1.cov <- sdev.id1.cov
 	part1.list$sigma.id1 <- sigma.id1 
 	part1.list$coef.id2 <- coef.id2 
-	part1.list$sdev.id2 <- sdev.id2 
+	part1.list$sdev.id2.cov <- sdev.id2.cov
 	part1.list$sigma.id2 <- sigma.id2
 	part1.list$coef.id3 <- coef.id3 
-	part1.list$sdev.id3 <- sdev.id3 
+	part1.list$sdev.id3.cov <- sdev.id3.cov
 	part1.list$sigma.id3 <- sigma.id3
 	part1.list$coef.id4 <- coef.id4 
-	part1.list$sdev.id4 <- sdev.id4 
+	part1.list$sdev.id4.cov <- sdev.id4.cov
 	part1.list$sigma.id4 <- sigma.id4
 	
 	part1.list$R2.g1.1 <- R2.g1.1 
